@@ -200,7 +200,8 @@ class Item(BaseItem):
             """Make URLs for the separate tabs of Collections details page."""
             self._make_URL(tab, self.details + "&tab={tab}".format(tab=tab))
 
-        DEFAULT_URL_FORMAT = '{0.session.protocol}//archive.org/{path}/{0.identifier}'
+        DEFAULT_URL_FORMAT = ('{0.session.protocol}//{0.session.host}'
+                              '/{path}/{0.identifier}')
 
         def _make_URL(self, path, url_format=DEFAULT_URL_FORMAT):
             setattr(self, path, url_format.format(self._itm_obj, path=path))
@@ -215,6 +216,127 @@ class Item(BaseItem):
             item_metadata = self.session.get_metadata(self.identifier, **kwargs)
         self.load(item_metadata)
 
+    def get_task_summary(self, params=None, request_kwargs=None):
+        """Get a summary of the item's pending tasks.
+
+        :type params: dict
+        :param params: (optional) Params to send with your request.
+
+        :rtype: dict
+        """
+        return self.session.get_tasks_summary(self.identifier, params, request_kwargs)
+
+    def no_tasks_pending(self, params=None, request_kwargs=None):
+        """Get a list of completed catalog tasks for the item.
+
+        :type params: dict
+        :param params: (optional) Params to send with your request.
+
+        :rtype: bool
+        :returns: `True` if no tasks are pending, otherwise `False`.
+        """
+        return all(x == 0 for x in self.task_summary(params, request_kwargs).values())
+
+    def get_all_item_tasks(self, params=None, request_kwargs=None):
+        """Get a list of all tasks for the item, pending and complete.
+
+        :type params: dict
+        :param params: (optional) Query parameters, refer to
+                       `Tasks API
+                       <https://archive.org/services/docs/api/tasks.html>`_
+                       for available parameters.
+
+        :type request_kwargs: dict
+        :param request_kwargs: (optional) Keyword arguments that
+                               :py:func:`requests.get` takes.
+
+        :rtype: List[CatalogTask]
+        """
+        params.update(dict(catalog=1, history=1))
+        return self.session.get_tasks(self.identifier, params, request_kwargs)
+
+    def get_history(self, params=None, request_kwargs=None):
+        """Get a list of completed catalog tasks for the item.
+
+        :type params: dict
+        :param params: (optional) Params to send with your request.
+
+        :rtype: list
+        :returns: A list of task dicts.
+
+        :rtype: List[CatalogTask]
+        """
+        history = list()
+        for t in self.session.iter_history(self.identifier, params, request_kwargs):
+            history.append(t)
+        return history
+
+    def get_catalog(self, params=None, request_kwargs=None):
+        """Get a list of pending catalog tasks for the item.
+
+        :type params: dict
+        :param params: (optional) Params to send with your request.
+
+        :rtype: list
+        :returns: A list of task dicts.
+
+        :rtype: List[CatalogTask]
+        """
+        catalog = list()
+        for t in self.session.iter_catalog(self.identifier, params, request_kwargs):
+            catalog.append(t)
+        return catalog
+
+    def undark(self, comment, priority=None, data=None, request_kwargs=None):
+        """Undark the item.
+
+        :type comment: str
+        :param comment: The curation comment explaining reason for
+                        undarking item
+
+        :type priority: str or int
+        :param priority: (optional) The task priority.
+
+        :type data: dict
+        :param data: (optional) Additional parameters to submit with
+                     the task.
+
+        :rtype: :class:`requests.Response`
+        """
+        r = self.session.submit_task(self.identifier,
+                                     'make_undark.php',
+                                     comment=comment,
+                                     priority=priority,
+                                     data=data,
+                                     request_kwargs=request_kwargs)
+        r.raise_for_status()
+        return r
+
+    def dark(self, comment, priority=None, data=None, request_kwargs=None):
+        """Dark the item.
+
+        :type comment: str
+        :param comment: The curation comment explaining reason for
+                        darking item
+
+        :type priority: str or int
+        :param priority: (optional) The task priority.
+
+        :type data: dict
+        :param data: (optional) Additional parameters to submit with
+                     the task.
+
+        :rtype: :class:`requests.Response`
+        """
+        r = self.session.submit_task(self.identifier,
+                                     'make_dark.php',
+                                     comment=comment,
+                                     priority=priority,
+                                     data=data,
+                                     request_kwargs=request_kwargs)
+        r.raise_for_status()
+        return r
+
     def get_file(self, file_name, file_metadata=None):
         """Get a :class:`File <File>` object for the named file.
 
@@ -410,7 +532,9 @@ class Item(BaseItem):
                 print(msg, end='')
 
         errors = list()
+        downloaded = 0
         responses = list()
+
         for f in files:
             if no_directory:
                 path = f.name
@@ -424,13 +548,20 @@ class Item(BaseItem):
                            no_change_timestamp, params)
             if return_responses:
                 responses.append(r)
+
             if r is False:
                 errors.append(f.name)
+            else:
+                downloaded += 1
+
         if silent is False and verbose is False and dry_run is False:
             if errors:
                 print(' - errors')
+            elif not downloaded:
+                print(' - download failed')
             else:
                 print(' - success')
+
         if return_responses:
             return responses
         else:
@@ -485,9 +616,10 @@ class Item(BaseItem):
         debug = False if debug is None else debug
         request_kwargs = {} if not request_kwargs else request_kwargs
 
-        url = '{protocol}//archive.org/metadata/{identifier}'.format(
+        url = '{protocol}//{host}/metadata/{identifier}'.format(
             protocol=self.session.protocol,
-            identifier=self.identifier)
+            identifier=self.identifier,
+            host=self.session.host)
         # TODO: currently files and metadata targets do not support dict's,
         # but they might someday?? refactor this check.
         source_metadata = self.item_metadata
