@@ -35,12 +35,16 @@ import sys
 import logging
 import platform
 import warnings
+try:
+    import ujson as json
+except ImportError:
+    import json
 
 import requests.sessions
 from requests.utils import default_headers
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3 import Retry
-from six.moves.urllib.parse import urlparse
+from six.moves.urllib.parse import urlparse, unquote
 
 from internetarchive import __version__
 from internetarchive.config import get_config
@@ -102,7 +106,15 @@ class ArchiveSession(requests.sessions.Session):
         self.config_file = config_file
         self.cookies.update(self.config.get('cookies', {}))
         self.secure = self.config.get('general', {}).get('secure', True)
+        self.host = self.config.get('general', {}).get('host', 'archive.org')
+        if 'archive.org' not in self.host:
+            self.host += '.archive.org'
         self.protocol = 'https:' if self.secure else 'http:'
+        user_email = self.config.get('cookies', dict()).get('logged-in-user')
+        if user_email:
+            user_email = user_email.split(';')[0]
+            user_email = unquote(user_email)
+        self.user_email = user_email
         self.access_key = self.config.get('s3', {}).get('access')
         self.secret_key = self.config.get('s3', {}).get('secret')
         self.http_adapter_kwargs = http_adapter_kwargs
@@ -255,7 +267,7 @@ class ArchiveSession(requests.sessions.Session):
         :returns: Metadat API response.
         """
         request_kwargs = {} if not request_kwargs else request_kwargs
-        url = '{0}//archive.org/metadata/{1}'.format(self.protocol, identifier)
+        url = '{0}//{1}/metadata/{2}'.format(self.protocol, self.host, identifier)
         if 'timeout' not in request_kwargs:
             request_kwargs['timeout'] = 12
         try:
@@ -297,60 +309,6 @@ class ArchiveSession(requests.sessions.Session):
                       request_kwargs=request_kwargs,
                       max_retries=max_retries)
 
-    def get_task_log(self, task_id, request_kwargs=None):
-        return CatalogTask.get_task_log(task_id, self, request_kwargs)
-
-    def get_tasks(self,
-                  identifier=None,
-                  task_id=None,
-                  task_type=None,
-                  params=None,
-                  config=None,
-                  verbose=None,
-                  request_kwargs=None):
-        """Get tasks from the Archive.org catalog. ``internetarchive`` must be configured
-        with your logged-in-* cookies to use this function. If no arguments are provided,
-        all queued tasks for the user will be returned.
-
-        :type identifier: str
-        :param identifier: (optional) The Archive.org identifier for which to retrieve
-                           tasks for.
-
-        :type task_id: int or str
-        :param task_id: (optional) The task_id to retrieve from the Archive.org catalog.
-
-        :type task_type: str
-        :param task_type: (optional) The type of tasks to retrieve from the Archive.org
-                          catalog. The types can be either "red" for failed tasks, "blue"
-                          for running tasks, "green" for pending tasks, "brown" for paused
-                          tasks, or "purple" for completed tasks.
-
-        :type params: dict
-        :param params: (optional) The URL parameters to send with each request sent to the
-                       Archive.org catalog API.
-
-        :type config: dict
-        :param secure: (optional) Configuration options for session.
-
-        :type verbose: bool
-        :param verbose: (optional) Set to ``True`` to retrieve verbose information for
-                        each catalog task returned. verbose is set to ``True`` by default.
-
-        :returns: A set of :class:`CatalogTask` objects.
-        """
-        request_kwargs = {} if not request_kwargs else request_kwargs
-        _catalog = Catalog(self,
-                           identifier=identifier,
-                           task_id=task_id,
-                           params=params,
-                           config=config,
-                           verbose=verbose,
-                           request_kwargs=request_kwargs)
-        if task_type:
-            return eval('_catalog.{0}_rows'.format(task_type.lower()))
-        else:
-            return _catalog.tasks
-
     def s3_is_overloaded(self, identifier=None, access_key=None, request_kwargs=None):
         request_kwargs = {} if not request_kwargs else request_kwargs
         if 'timeout' not in request_kwargs:
@@ -375,6 +333,150 @@ class ArchiveSession(requests.sessions.Session):
         else:
             return True
 
+    def submit_task(self, identifier, cmd, comment=None, priority=None, data=None,
+                    request_kwargs=None):
+        """Submit an archive.org task.
+
+        :type identifier: str
+        :param identifier: Item identifier.
+
+        :type cmd: str
+        :param cmd: Task command to submit, see
+                    `supported task commands
+                    <https://archive.org/services/docs/api/tasks.html#supported-tasks>`_.
+
+        :type comment: str
+        :param comment: (optional) A reasonable explanation for why the
+                        task is being submitted.
+
+        :type priority: int
+        :param priority: (optional) Task priority from 10 to -10
+                         (default: 0).
+
+        :type data: dict
+        :param data: (optional) Extra POST data to submit with
+                     the request. Refer to `Tasks API Request Entity
+                     <https://archive.org/services/docs/api/tasks.html#request-entity>`_.
+
+        :type request_kwargs: dict
+        :param request_kwargs: (optional) Keyword arguments to be used in
+                               :meth:`requests.sessions.Session.post` request.
+
+        :rtype: :class:`requests.Response`
+        """
+        c = Catalog(self, request_kwargs)
+        r = c.submit_task(identifier, cmd, comment=comment, priority=priority, data=data)
+        return r
+
+    def iter_history(self, identifier, params=None, request_kwargs=None):
+        """A generator that returns completed tasks.
+
+        :type identifier: str
+        :param identifier: (optional) Item identifier.
+
+        :type params: dict
+        :param params: (optional) Query parameters, refer to
+                       `Tasks API
+                       <https://archive.org/services/docs/api/tasks.html>`_
+                       for available parameters.
+
+        :type request_kwargs: dict
+        :param request_kwargs: (optional) Keyword arguments to be used in
+                               :meth:`requests.sessions.Session.get` request.
+
+        :rtype: collections.Iterable[CatalogTask]
+        """
+        params = dict() if not params else params
+        params.update(dict(identifier=identifier, catalog=0, summary=0, history=1))
+        c = Catalog(self, request_kwargs)
+        for j in c.iter_tasks(params):
+            yield j
+
+    def iter_catalog(self, identifier=None, params=None, request_kwargs=None):
+        """A generator that returns queued or running tasks.
+
+        :type identifier: str
+        :param identifier: (optional) Item identifier.
+
+        :type params: dict
+        :param params: (optional) Query parameters, refer to
+                       `Tasks API
+                       <https://archive.org/services/docs/api/tasks.html>`_
+                       for available parameters.
+
+        :type request_kwargs: dict
+        :param request_kwargs: (optional) Keyword arguments to be used in
+                               :meth:`requests.sessions.Session.get` request.
+
+        :rtype: collections.Iterable[CatalogTask]
+        """
+        params = dict() if not params else params
+        params.update(dict(identifier=identifier, catalog=1, summary=0, history=0))
+        c = Catalog(self, request_kwargs)
+        for j in c.iter_tasks(params):
+            yield j
+
+    def get_tasks_summary(self, identifier=None, params=None, request_kwargs=None):
+        """Get the total counts of catalog tasks meeting all criteria,
+        organized by run status (queued, running, error, and paused).
+
+        :type identifier: str
+        :param identifier: (optional) Item identifier.
+
+        :type params: dict
+        :param params: (optional) Query parameters, refer to
+                       `Tasks API
+                       <https://archive.org/services/docs/api/tasks.html>`_
+                       for available parameters.
+
+        :type request_kwargs: dict
+        :param request_kwargs: (optional) Keyword arguments to be used in
+                               :meth:`requests.sessions.Session.get` request.
+
+        :rtype: dict
+        """
+        c = Catalog(self, request_kwargs)
+        return c.get_summary(identifier=identifier, params=params)
+
+    def get_tasks(self, identifier=None, params=None, request_kwargs=None):
+        """Get a list of all tasks meeting all criteria.
+        The list is ordered by submission time.
+
+        :type identifier: str
+        :param identifier: (optional) The item identifier, if provided
+                           will return tasks for only this item filtered by
+                           other criteria provided in params.
+
+        :type params: dict
+        :param params: (optional) Query parameters, refer to
+                       `Tasks API
+                       <https://archive.org/services/docs/api/tasks.html>`_
+                       for available parameters.
+
+        :type request_kwargs: dict
+        :param request_kwargs: (optional) Keyword arguments to be used in
+                               :meth:`requests.sessions.Session.get` request.
+
+        :rtype: List[CatalogTask]
+        """
+        c = Catalog(self, request_kwargs)
+        return c.get_tasks(identifier=identifier, params=params)
+
+    def get_task_log(self, task_id, request_kwargs=None):
+        """Get a task log.
+
+        :type task_id: str or int
+        :param task_id: The task id for the task log you'd like to fetch.
+
+        :type request_kwargs: dict
+        :param request_kwargs: (optional) Keyword arguments that
+                               :py:class:`requests.Request` takes.
+
+        :rtype: str
+        :returns: The task log as a string.
+        """
+        return CatalogTask.get_task_log(task_id, self, request_kwargs)
+
     def send(self, request, **kwargs):
         # Catch urllib3 warnings for HTTPS related errors.
         insecure = False
@@ -399,7 +501,7 @@ class ArchiveSession(requests.sessions.Session):
         if insecure:
             from requests.exceptions import RequestException
             msg = ('You are attempting to make an HTTPS request on an insecure platform,'
-                   ' please see:\n\n\thttps://internetarchive.readthedocs.org'
-                   '/en/latest/troubleshooting.html#https-issues\n')
+                   ' please see:\n\n\thttps://archive.org/services/docs/api'
+                   '/internetarchive/troubleshooting.html#https-issues\n')
             raise RequestException(msg)
         return r
